Index: /trunk/Ohana/src/getstar/src/WriteImageFITS.c
===================================================================
--- /trunk/Ohana/src/getstar/src/WriteImageFITS.c	(revision 13092)
+++ /trunk/Ohana/src/getstar/src/WriteImageFITS.c	(revision 13093)
@@ -1,5 +1,7 @@
 # include "dvoImageExtract.h"
 
-/* given image, find catalog images which overlap it */
+/* given image, find catalog images which overlap it.  this function actually creates an
+ * image-less file, filling in the header, but not the pixels.
+ */
 int WriteImageFITS (FILE *f, Image *image) {
   
@@ -18,13 +20,15 @@
   }
   gfits_create_header (&header);
+  gfits_modify (&header, "NAXIS", "%d", 1, 0);
 
   if (image) {
     PutCoords (&image[0].coords, &header);
   }
-  /* create (NOT empty) data matrix */
-  gfits_create_matrix (&header, &matrix);
+  /* do not create data matrix - the matrix is defined to be empty (NAXIS=0)
+     gfits_create_matrix (&header, &matrix);
+  */
+  gfits_fwrite_header  (f, &header);
 
-  gfits_fwrite_header  (f, &header);
-  gfits_fwrite_matrix  (f, &matrix);
+  // gfits_fwrite_matrix  (f, &matrix);
   return (TRUE);
 
